set.similarity: Set similarity function for Geary-Moran type TDT tests
Description
Haplotypes are only similar if they are IBS at the focal locus. The extent of
the similar region to each side is determined by stepping outwards until
the haplotypes are no longer IBS, the region being assumed to end midway
between the last IBS locus and the first non-IBS locus. If the haplotypes are
IBS at the last locus, half the "off-end" distance is scored. The similarity
is defined as the total length of this shared region raised to some power.
# To do a Geary_Moran test on a 10 marker haplotype gaps <- c(0, 50, 60, 80, 20, 30, 50, 40, 50, 100, 0)
set.similarity(nloci=10, spacing=gaps, power=0.5)
test <- tdt.quad(hap.use, funct=T)