tdt.rr: Calculate haplotype relative risks in TDT studies
Description
The p-value is the conventional "exact" test based on the binomial distribution
of transmissions. The estimated relative risks use a Bayesian method,
recommended because of the multiplicity problem. the prior is a beta
distribution of the second kind, defined by two "degrees of freedom"
parameters. Note that the prior mean is prior.df[1]/prior.df[2] and that
Bayes estimates based on small numbers of transmissions are pulled in towards
this. A "realistic" choice of these parameters is recommended, and to aid
this, the function returns credible intervals using the prior alone as well as
the a posteriori interval for each haplotype.
A list containing the transmitted and untransmitted haplotypes. This would
normally be computed using tdt.select.
prior.df
a vector of length two containing the degree of freedom parameters for the
prior distribution of the haplotype relative risk - a beta distribution of the
second kind.
prob
The probability levels for Bayesian credibility intervals for the haplotype
relative risks.
Value
A matrix containing the numbers of transmitted and untransmitted haplotypes,
the (binomial) p-values, the Bayes estimates of the haplotype relative risks,
and the lower and upper bounds of the credible interval. The prior estimate
and credible interval is also shown.
References
Spielman R., McGinnis R., and Ewens, W. (1993) Transmission tests for linkage
disequilibrium. American Journal of Human Genetics, 52, 506-16.
# Select the sub-haplotype made up from the first two markers and # print tables of TDT tests and haplotype realtaive risks hap.use <- tdt.select(haps, markers=1:2)
rr <- tdt.rr(hap.use)
rr